@@ -41,7 +41,7 @@ import os
 import time
 
 import plot_functions as pfunc
-import functions as func
+
 
 colormap = 'terrain'
 
@@ -83,7 +83,7 @@ def cal_err_mag (I, I_err):
 def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
               user_order=None, user_list=None, sky_box=[100, 100],
               deblend='off', band='R', nsigma=2, npixels=5, dilate_size=11,
-              outputfile='properties.dat', eta=0.2):
+              outputfile='properties.dat', eta=0.2, show_plot='yes'):
 
     idg =np.where(tab_gal['gal']==gal)[0][0]
     D = tab_gal['vel'][idg]/H
@@ -98,7 +98,8 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     print (Fore.BLUE +'Minimum detection area {:.1f} kcp^2 = {:.0f} pix'.format(areagal,
            area_min))
 
-    if np.char.startswith(tab_gal['field'][idg], 'MC'):
+    out = conn.checkcoords(tab_gal['ra'][idg], tab_gal['dec'][idg])
+    if np.char.startswith(out['field'], 'MC'):
         print (Fore.RED + "\n==================================================")
         print (Fore.RED +"\n\nThis galaxy is in the Magellanic Clouds Tiles, therefore")
         print (Fore.RED +"there is not a photometric catalog avaible for it, ")
@@ -132,29 +133,29 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                      band,
                    filepath=patht[0:-3])
 
-    path = f'tables/{gal}_basic.tab'
-    patht = 'tables/{}_basic.tab'.format(gal[:-1])
-    if os.path.exists(path)  or os.path.exists(patht):
-        print (f'\nthe table {path} already exist')
-        try:
-            tab0 = Table.read(path, format='ascii')
-        except:
-            tab0 = Table.read(patht, format='ascii')
-    else:
-        query_txt = ("SELECT det.ID, det.RA, det.DEC, det.A, det.B, det.Theta" +
-                     ", det.KRON_rADIUS, det.CLASS_STAR, det.FIELD, claf.CLASS"+
-                     ", claf.model_flag, claf.PROB_GAL, claf.PROB_QSO, " +
-                     "claf.PROB_STAR  FROM idr3.all_idr3 as det join"+
-                     " idr3.vac_star_galaxy_quasar as claf on "+
-                     "claf.ID = det.ID WHERE 1 = CONTAINS( POINT('ICRS', " +
-                     "det.ra, det.dec), CIRCLE('ICRS'," +
-                     str(tab_gal['ra'][idg]) + "," + str(tab_gal['dec'][idg]) +
-                     ","+str(10/3600.)+"))")
-
-        print ("\nDoing the following query ...\n", query_txt)
-        tab0=conn.query(query_txt)
-
-        tab0.write(f'tables/{gal}_basic.tab', format='ascii')
+#    path = f'tables/{gal}_basic.tab'
+#    patht = 'tables/{}_basic.tab'.format(gal[:-1])
+#    if os.path.exists(path)  or os.path.exists(patht):
+#        print (f'\nthe table {path} already exist')
+#        try:
+#            tab0 = Table.read(path, format='ascii')
+#        except:
+#            tab0 = Table.read(patht, format='ascii')
+#    else:
+#        query_txt = ("SELECT det.ID, det.RA, det.DEC, det.A, det.B, det.Theta" +
+#                     ", det.KRON_rADIUS, det.CLASS_STAR, det.FIELD, claf.CLASS"+
+#                     ", claf.model_flag, claf.PROB_GAL, claf.PROB_QSO, " +
+#                     "claf.PROB_STAR  FROM idr3.all_idr3 as det join"+
+#                     " idr3.vac_star_galaxy_quasar as claf on "+
+#                     "claf.ID = det.ID WHERE 1 = CONTAINS( POINT('ICRS', " +
+#                     "det.ra, det.dec), CIRCLE('ICRS'," +
+#                     str(tab_gal['ra'][idg]) + "," + str(tab_gal['dec'][idg]) +
+#                     ","+str(10/3600.)+"))")
+#
+#        print ("\nDoing the following query ...\n", query_txt)
+#        tab0=conn.query(query_txt)
+#
+#        tab0.write(f'tables/{gal}_basic.tab', format='ascii')
 
 
 
@@ -163,14 +164,30 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
 #    zp = ZP[band][id_zp]
 #    print ('\nid_zp_table:',id_zp,'ZP',zp,'Field:', tab0['Field'][0])
 
+
+    Field = out['field']
+    #DR_array_all.append(out['dr'])
+    print('#############################')
+    print(Fore.BLUE +'\n\n Field: {}'.format(Field))
+    print('#############################')
+
     path = f'tables/{gal}_fwhm.tab'
     patht = 'tables/{}_fwhm.tab'.format(gal[:-1])
-    if os.path.exists(path) or os.path.exists(patht):
-        print (f'\nThe table {path} already exist')
-        try:
+    pathtt = 'tables/{}_fwhm.tab'.format(Field)
+    if os.path.exists(path) or os.path.exists(patht) or os.path.exists(pathtt):
+        #try:
+        #     tab_fwhm = Table.read(path, format='ascii')
+        #except:
+        #    tab_fwhm = Table.read(patht, format='ascii')
+        if os.path.exists(path):
             tab_fwhm = Table.read(path, format='ascii')
-        except:
+            print (f'\nThe table {path} already exist')
+        if os.path.exists(patht):
             tab_fwhm = Table.read(patht, format='ascii')
+            print (f'\nThe table {patht} already exist')
+        if os.path.exists(pathtt):
+            tab_fwhm = Table.read(pathtt, format='ascii')
+            print (f'\nThe table {pathtt} already exist')
     else:
         query_txt1 = ("SELECT det.ID, det.RA, det.DEC, det.A, det.B, " +
                       "det.Theta, det.KRON_rADIUS, det.r_auto, det.CLASS_STAR," +
@@ -179,13 +196,14 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                       " claf.PROB_QSO, claf.PROB_STAR" +
                       "  FROM idr3.all_idr3 as det join " +
                       "idr3.vac_star_galaxy_quasar as claf on " +
-                      "claf.ID = det.ID WHERE det.FIELD = '" + tab0['Field'][0] +
+                      "claf.ID = det.ID WHERE det.FIELD = '" +  str(Field) +   #tab0['Field'][0] +
                       "' and claf.PROB_STAR > 0.8 " +
                       "and det.r_auto >13 and det.r_auto<17 ")
         print ("\nDoing the following query ...\n", query_txt1)
         tab_fwhm=conn.query(query_txt1)
 
-        tab_fwhm.write(f'tables/{gal}_fwhm.tab', format='ascii')
+        #tab_fwhm.write(f'tables/{gal}_fwhm.tab', format='ascii')
+        tab_fwhm.write(f'tables/{Field}_fwhm.tab', format='ascii')
 
     print(Fore.BLACK + '\n\nZP and mean PSF of the Field')
     print('--------------------------------')
@@ -195,7 +213,7 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     id_zp = np.where(ZP['field']==tab_fwhm['Field'][0])[0][0]
     zp = ZP[band][id_zp]
     print ('\nid_zp_table:', id_zp, 'ZP={:.1f}'.format(zp),
-           'Field:', tab0['Field'][0])
+           'Field:', out['field'])
 
 
     psf_g= np.round(np.nanmedian(tab_fwhm['FWHM']),1)
@@ -235,9 +253,10 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     plt.imshow(mask_g, origin='lower')
     plt.savefig('images/fig_'+gal+'_{}kpc_sky_mask.png'.format(size_image_phy),
                     bbox_inches='tight')
-    plt.show()
-
-
+    if show_plot=='yes':
+        plt.show()
+    else:
+        plt.close()
 
     mean_sky, median_sky, std_sky = sigma_clipped_stats(imag, sigma=11.0,
                                                               mask=mask_g)
@@ -263,7 +282,10 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     plt.imshow(bkg.background, origin='lower')
     plt.savefig('images/fig_'+gal+'_{}kpc_sky.png'.format(size_image_phy),
                     bbox_inches='tight')
-    plt.show()
+    if show_plot=='yes':
+        plt.show()
+    else:
+        plt.close()
 
     pathgal = tab_gal['gal'][idg]+'_{}kpc'.format(size_image_phy)
     fits.writeto('fits_images/' + pathgal + '_sky.fits', bkg.background, overwrite=True)
@@ -304,7 +326,10 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
         print ("Segmentation map without debleding")
         plt.figure(figsize=(6.5,6.5))
         plt.imshow(segm, origin='lower')
-        plt.show()
+        if show_plot=='yes':
+            plt.show()
+        else:
+            plt.close()
         segm = deblend_sources(imag, segm, npixels=npixels_g,
                                 #kernel=kernel,
                                 nlevels=32, contrast=0.001)
@@ -327,9 +352,13 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     plt.imshow(segm, origin='lower', cmap='gray')
 
     saven = 'images/fig_'+tab_gal['gal'][idg]+'_{}kpc_segm.png'.format(size_image_phy)
-    plt.show()
     plt.savefig(saven, bbox_inches='tight')
 
+    if show_plot=='yes':
+        plt.show()
+    else:
+        plt.close()
+
     #segmap=np.copy(segm.data)
 
     print(Fore.RED + '\n\nRunning Statmorph')
@@ -357,7 +386,7 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
            morph = source_morphs[gali]
            plot_stat(morph, gal+listl[i], imag, imagm, median_sky_g, area,t, zp,
                          psfg,psf_g, sc_imag, arc_kpc, size_image_phy,
-                         outputfile=outputfile)
+                         outputfile=outputfile, show_plot=show_plot)
 
            data = ascii.read(outputfile)
 
@@ -381,7 +410,7 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
            morph = source_morphs[gali]
            plot_stat(morph, gal + user_list[i], imag, imagm, median_sky_g, area,
                      t, zp, psfg,psf_g, sc_imag, arc_kpc, size_image_phy,
-                     outputfile=outputfile)
+                     outputfile=outputfile, show_plot=show_plot)
 
            data = ascii.read(outputfile)
 
@@ -600,7 +629,8 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                  region='circle', server=None, limtvel=500, xtpos=10, ytpos=20,
                  deltay=10, sky_box=[100, 100], deblend='off', psf=1,
                  usesimbad='no', band='R', field_size_phy=100, nsigma=2,
-                 npixels=5, dilate_size=11):
+                 npixels=5, dilate_size=11, eta=0.2, show_plot='yes', run_auto='no',
+                 outputfile='properties.dat'):
 
     idg =np.where(tab_gal['gal']==gal)[0][0]
     D = tab_gal['vel'][idg]/H
@@ -627,8 +657,8 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     print (Fore.BLUE +'Minimum detection area {:.1f} kcp^2 = {:.0f} pix'.format(areagal,
            area_min))
 
-
-    if np.char.startswith(tab_gal['field'][idg], 'MC'):
+    out = conn.checkcoords(tab_gal['ra'][idg], tab_gal['dec'][idg])
+    if np.char.startswith(out['field'], 'MC'):
         print (Fore.RED + "\n==================================================")
         print (Fore.RED +"\n\nThis galaxy is in the Magellanic Clouds Tiles, therefore")
         print (Fore.RED +"there is not a photometric catalog avaible for it, ")
@@ -669,7 +699,9 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
         radsimbad = size_image_phy
 
     print(Fore.BLACK +'')
-    outsimbad = cat_simbad (gal, tab_gal, size_image_phy=radsimbad, region=region,
+
+    if run_auto=='no':
+        outsimbad = cat_simbad (gal, tab_gal, size_image_phy=radsimbad, region=region,
                             limtvel=limtvel, server=server)
 
 
@@ -756,7 +788,8 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
         print (f'\nThe image {path} already exist')
 
 
-    plot_simbad(gal, tab_gal, conn, size_image_phy=radsimbad, table=outsimbad,
+    if run_auto=='no':
+        plot_simbad(gal, tab_gal, conn, size_image_phy=radsimbad, table=outsimbad,
                 add_object=False, xtpos=xtpos, ytpos=ytpos, deltay=deltay,
                 print_arp='no', print_scale='no', usesimbad=usesimbad, band=band)
 
@@ -783,7 +816,10 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                               dilate_size=dilate_size)
     fig=plt.figure(figsize=(6.5,6.5))
     plt.imshow(mask_g, origin='lower')
-    plt.show()
+    if show_plot=='yes':
+        plt.show()
+    else:
+        plt.close()
 
     mean_sky, median_sky, std_sky = sigma_clipped_stats(imag, sigma=11.0,
                                                               mask=mask_g)
@@ -815,7 +851,10 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     print ("Background map")
     fig=plt.figure(figsize=(6.5,6.5))
     plt.imshow(bkg.background, origin='lower')
-    plt.show()
+    if show_plot=='yes':
+        plt.show()
+    else:
+        plt.close()
 
     # Segmentation map
     sigma = psf * gaussian_fwhm_to_sigma
@@ -834,10 +873,14 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
         print ("Segmentation map without debleding")
         fig=plt.figure(figsize=(6.5, 6.5))
         plt.imshow(segm, origin='lower')
+        if show_plot=='yes':
+            plt.show()
+        else:
+            plt.close()
         segm = deblend_sources(imag, segm, npixels=npixels_g,
                                #kernel=kernel,
                                 nlevels=32, contrast=0.001)
-        plt.show()
+
     #plt.imshow(segm_deblend, origin='lower')
 
 
@@ -883,64 +926,85 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     cb = plt.colorbar(imseg)
     cb.ax.minorticks_on()
     plt.minorticks_on()
-    plt.show()
+    if show_plot=='yes':
+        plt.show()
+    else:
+        plt.close()
     #fits.writeto('test.fits', segmc, overwrite=True)
 
-    if usesimbad=='no':
-        path = 'images_100k/' + tab_gal['gal'][idg] + '_100_kpc_radius.png'
-    else:
-        path = 'images/{}_simbad_{}kpc.png'.format(gal, radsimbad)
-    if not os.path.exists(path):
-        print ('\nThe image of 100 kpc is not available')
-        fig=plt.figure(figsize=(17,8))
-        plt.subplot(121)
-        plt.imshow(segm, origin='lower', cmap='gray',
-                   extent=np.array([-1,1,-1,1])*size_image_kpc)
-        plt.xlabel('x (kpc)')
-        plt.ylabel('y (kpc)')
-        plt.minorticks_on()
-        plt.subplot(122)
-        plt.imshow(ima50, extent=np.array([-1,1,-1,1])*size_image_kpc)
-        plt.grid()
-        plt.xlabel('x (kpc)')
-        plt.minorticks_on()
-        plt.show()
-
-
-    else:
-        ima100=plt.imread(path)
-        fig=plt.figure(figsize=(21,8))
-        plt.subplot(131)
-        plt.imshow(segm, origin='lower', cmap='gray',
-                   extent=np.array([-1,1,-1,1])*size_image_kpc)
-        plt.xlabel('x (kpc)')
-        plt.ylabel('y (kpc)')
-        plt.minorticks_on()
-        plt.subplot(132)
-        plt.imshow(ima50,extent=np.array([-1,1,-1,1])*size_image_kpc)
-        plt.grid()
-        plt.xlabel('x (kpc)')
-        plt.minorticks_on()
-        plt.subplot(133)
+    if show_plot=='yes':
         if usesimbad=='no':
-            size_image=((100/arc_kpc)/0.55)*2
-            size_image_kpc = int(size_image)*0.5*0.55*arc_kpc
+            path = 'images_100k/' + tab_gal['gal'][idg] + '_100_kpc_radius.png'
         else:
-            size_image= 300
-            pix_scima = ((radsimbad*2)/arc_kpc)/size_image
-            size_image_kpc = int(size_image)*0.5*pix_scima*arc_kpc
-        plt.imshow(ima100, extent=np.array([-1,1,-1,1])*size_image_kpc)
-        plt.grid()
-        plt.xlabel('x (kpc)')
-        plt.minorticks_on()
-        plt.show()
+            path = 'images/{}_simbad_{}kpc.png'.format(gal, radsimbad)
+        if not os.path.exists(path):
+            print ('\nThe image of 100 kpc is not available')
+            fig=plt.figure(figsize=(17,8))
+            plt.subplot(121)
+            plt.imshow(segm, origin='lower', cmap='gray',
+                       extent=np.array([-1,1,-1,1])*size_image_kpc)
+            plt.xlabel('x (kpc)')
+            plt.ylabel('y (kpc)')
+            plt.minorticks_on()
+            plt.subplot(122)
+            plt.imshow(ima50, extent=np.array([-1,1,-1,1])*size_image_kpc)
+            plt.grid()
+            plt.xlabel('x (kpc)')
+            plt.minorticks_on()
+            plt.show()
+
+
+        else:
+            ima100=plt.imread(path)
+            fig=plt.figure(figsize=(21,8))
+            plt.subplot(131)
+            plt.imshow(segm, origin='lower', cmap='gray',
+                       extent=np.array([-1,1,-1,1])*size_image_kpc)
+            plt.xlabel('x (kpc)')
+            plt.ylabel('y (kpc)')
+            plt.minorticks_on()
+            plt.subplot(132)
+            plt.imshow(ima50,extent=np.array([-1,1,-1,1])*size_image_kpc)
+            plt.grid()
+            plt.xlabel('x (kpc)')
+            plt.minorticks_on()
+            plt.subplot(133)
+            if usesimbad=='no':
+                size_image=((100/arc_kpc)/0.55)*2
+                size_image_kpc = int(size_image)*0.5*0.55*arc_kpc
+            else:
+                size_image= 300
+                pix_scima = ((radsimbad*2)/arc_kpc)/size_image
+                size_image_kpc = int(size_image)*0.5*pix_scima*arc_kpc
+            plt.imshow(ima100, extent=np.array([-1,1,-1,1])*size_image_kpc)
+            plt.grid()
+            plt.xlabel('x (kpc)')
+            plt.minorticks_on()
+            plt.show()
+
+    if run_auto!='yes':
+        part0 = f"\n\nSL.phot_mod('{gal}', tab_gal, conn, size_image_phy={size_image_phy}, "
+        part1 = f""" snr_g = {snr_g}, areagal={areagal},sky_box = {sky_box},\n deblend ="{deblend}", """
+        part2 = f"""user_order=[1,2], user_list=["A","B"], band='{band}')"""
+        print(part0 + part1 + part2)
+
+        return outsimbad
+    else:
+        maxarea = int(segmc[int(segmc.shape[0]*.5), int(segmc.shape[1]*.5)])-1
+
+        part0 = f"\n\nSL.phot_mod('{gal}', tab_gal, conn, size_image_phy={size_image_phy}, "
+        part1 = f""" snr_g = {snr_g}, areagal={areagal},sky_box = {sky_box},\n deblend ="{deblend}", """
+        part2 = f"""user_order=[{maxarea}], user_list=[{band}], band='{band}')"""
+        print(part0 + part1 + part2)
+
+        phot_mod (gal, tab_gal, conn, size_image_phy=size_image_phy,
+                  snr_g = snr_g, areagal=areagal,
+                  user_order=[maxarea], user_list=[band], sky_box=sky_box,
+                  deblend=deblend, band=band, nsigma=nsigma, npixels=npixels,
+                  dilate_size=dilate_size, outputfile=outputfile, eta=eta,
+                  show_plot=show_plot)
 
-    part0 = f"\n\nSL.phot_mod('{gal}', tab_gal, conn, size_image_phy={size_image_phy}, "
-    part1 = f""" snr_g = {snr_g}, areagal={areagal},sky_box = {sky_box},\n deblend ="{deblend}", """
-    part2 = """user_order=[1,2], user_list=["A","B"])"""
-    print(part0 + part1 + part2)
 
-    return outsimbad
 
 def cat_simbad (GAL, tab_gal, size_image_phy=100, region='box', limtvel=500,
                 server=None):
@@ -1697,7 +1761,7 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
         plt.show()
     else:
         plt.close()
-    #fits.writeto('test.fits', segmc, overwrite=True)
+    fits.writeto('test.fits', segmc, overwrite=True)
 
     if run_auto == 'no':
 
@@ -1708,7 +1772,7 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
         print(part0 + part1 + part2 + part3)
     else:
 
-        maxarea = np.argmax(segm.areas)
+        maxarea = int(segmc[int(segmc.shape[0]*.5), int(segmc.shape[1]*.5)])-1
 
         part0 = f"\n\nSL.phot_mod_decals('{gal}', tab, size_image_phy={size_image_phy}, "
         part1 = f""" snr_g = {snr_g}, areagal={areagal}, band="{band}", """
@@ -1722,8 +1786,6 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
                            show_plot=show_plot)
 
 
-
-
 def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
                      band = 'r',
                      user_order=None, user_list=None, sky_box=[100, 100],
@@ -1876,9 +1938,22 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
     print ("\nFinal Segmentation map:")
     print ("-------------------------")
 
-    plt.figure(figsize=(6.5,6.5))
-    plt.imshow(segm, origin='lower', cmap='gray')
+    #plt.figure(figsize=(6.5,6.5))
+    #plt.imshow(segm, origin='lower', cmap='gray')
 
+    fig=plt.figure(figsize=(8,8))
+    segmc = np.copy(segm.data).astype(float)
+    segmc[segmc==0.0]=np.nan
+
+    imseg = plt.imshow(segmc, cmap='Paired', interpolation='nearest',
+                       origin='lower')
+    for i in np.arange(np.nanmax(segmc)):
+       pos=np.where(segmc==(i+1))
+       plt.text(pos[1][0], pos[0][0], str(int(i)), fontsize=30)
+
+    cb = plt.colorbar(imseg)
+    cb.ax.minorticks_on()
+    plt.minorticks_on()
     saven = 'images/fig_'+tab_gal['gal'][idg]+'_{}_{}kpc_segm.png'.format(
              band, size_image_phy)
     plt.savefig(saven, bbox_inches='tight')
@@ -1949,6 +2024,7 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
 
 def mass_decals(gal, tab_gal, size_image_phy, outputfile='properties.dat'):
 
+    import functions as func
     idg =np.where(tab_gal['gal']==gal[:-1])[0][0]
     D = tab_gal['vel'][idg]/H
     z_C = tab_gal['z'][idg]
